package F5::GlobalSettings;

use strict;
use warnings;

#----------------------------------------------------------------------

sub new {
    my($class, %params) = @_;
    my $self = {};
    bless $self, $class;
    $self->init(%params);
    return $self;
}

#----------------------------------------------------------------------

sub init {
    my($self, %params) = @_;
    $self->{client} = $params{client};
    $self->{logger} = $params{logger};
}

#----------------------------------------------------------------------

sub apply {
    my($self, %params) = @_;
    if ($params{cookie_protection_seed} && $params{cookie_protection_digest}) {
        my $msg = "Both seed and digest are configured";
        $self->{logger}->error($msg) if $self->{logger};
    }

    $self->{data_protection_cookie_configuration} = $params{cookie_protection_seed} || $params{cookie_protection_digest};
    $self->{logger}->info("Data protection cookie configuration=$self->{data_protection_cookie_configuration}")  if $self->{logger};
    $self->{logger}->info("Generating new data protection cookie") if $self->{logger};
    my $data_protection_rv = $self->{client}->update_data_protection($self->{client}->{session},
                                                                     F5::ASMConfig::CallFlags->new(),
                                                                     undef,
                                                                     F5::ASMConfig::DataProtection->new(secure_key => F5::DataProtection::generate_key($self->{data_protection_cookie_configuration})));
    return $self->{data_protection_cookie_configuration};
}

#----------------------------------------------------------------------

1;
